{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "samtools view cram to bam",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-b"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/output.bam"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#cram_to_bam.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#cram_to_bam.cwl/reference"
                }
            ],
            "id": "#cram_to_bam.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bam"
                    },
                    "id": "#cram_to_bam.cwl/bam"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "cram_to_bam workflow",
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#workflow.cwl/cram"
                },
                {
                    "type": "string",
                    "id": "#workflow.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#workflow.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#workflow.cwl/bam"
                }
            ],
            "steps": [
                {
                    "run": "#cram_to_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram",
                            "id": "#workflow.cwl/cram_to_bam/cram"
                        },
                        {
                            "source": "#workflow.cwl/reference",
                            "id": "#workflow.cwl/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/cram_to_bam/bam"
                    ],
                    "id": "#workflow.cwl/cram_to_bam"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#workflow.cwl/cram_to_bam/bam",
                            "id": "#workflow.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#workflow.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#workflow.cwl/index_bam"
                }
            ],
            "id": "#workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "cp",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/opt/samtools/bin/samtools",
                "index",
                "$(inputs.bam.path)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect alignment summary metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectAlignmentSummaryMetrics"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/AlignmentSummaryMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_alignment_summary_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "AlignmentSummaryMetrics.txt"
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/alignment_summary_metrics"
                }
            ],
            "id": "#collect_alignment_summary_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect gc bias metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectGcBiasMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/GcBiasMetrics.txt"
                },
                "CHART=",
                {
                    "valueFrom": "$(runtime.outdir)/GcBiasMetricsChart.pdf"
                },
                "S=",
                {
                    "valueFrom": "$(runtime.outdir)/GcBiasMetricsSummary.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_gc_bias_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_gc_bias_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_gc_bias_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "GcBiasMetrics.txt"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "GcBiasMetricsChart.pdf"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "GcBiasMetricsSummary.txt"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics_summary"
                }
            ],
            "id": "#collect_gc_bias_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect insert size metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectInsertSizeMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/InsertSizeMetrics.txt"
                },
                "H=",
                {
                    "valueFrom": "$(runtime.outdir)/InsertSizeHistogram.pdf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_insert_size_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_insert_size_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_insert_size_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "InsertSizeHistogram.pdf"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "InsertSizeMetrics.txt"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_metrics"
                }
            ],
            "id": "#collect_insert_size_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect WGS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectWgsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/WgsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_wgs_metrics.cwl/cram"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INTERVALS="
                    },
                    "id": "#collect_wgs_metrics.cwl/intervals"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_wgs_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "WgsMetrics.txt"
                    },
                    "id": "#collect_wgs_metrics.cwl/wgs_metrics"
                }
            ],
            "id": "#collect_wgs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools flagstat",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "flagstat"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "flagstat.out",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#samtools_flagstat.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_flagstat.cwl/flagstats",
                    "outputBinding": {
                        "glob": "flagstat.out"
                    }
                }
            ],
            "id": "#samtools_flagstat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "verify BAM ID",
            "baseCommand": "/usr/local/bin/verifyBamID",
            "arguments": [
                "--out",
                {
                    "valueFrom": "$(runtime.outdir)/VerifyBamId"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam"
                    },
                    "id": "#verify_bam_id.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf"
                    },
                    "id": "#verify_bam_id.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "VerifyBamId.depthSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "VerifyBamId.selfSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_metrics"
                }
            ],
            "id": "#verify_bam_id.cwl"
        },
        {
            "class": "Workflow",
            "label": "WGS QC workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#main/cram"
                },
                {
                    "type": "File",
                    "id": "#main/intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/omni_vcf"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "ALL_READS",
                    "id": "#main/picard_metric_accumulation_level"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/collect_alignment_summary_metrics/alignment_summary_metrics",
                    "id": "#main/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/samtools_flagstat/flagstats",
                    "id": "#main/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_gc_bias_metrics/gc_bias_metrics",
                    "id": "#main/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_gc_bias_metrics/gc_bias_metrics_chart",
                    "id": "#main/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_gc_bias_metrics/gc_bias_metrics_summary",
                    "id": "#main/gc_bias_metrics_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_insert_size_metrics/insert_size_histogram",
                    "id": "#main/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_insert_size_metrics/insert_size_metrics",
                    "id": "#main/insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/verify_bam_id/verify_bam_id_depth",
                    "id": "#main/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#main/verify_bam_id/verify_bam_id_metrics",
                    "id": "#main/verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/collect_wgs_metrics/wgs_metrics",
                    "id": "#main/wgs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_alignment_summary_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/collect_alignment_summary_metrics/cram"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/collect_alignment_summary_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_alignment_summary_metrics/reference"
                        }
                    ],
                    "out": [
                        "#main/collect_alignment_summary_metrics/alignment_summary_metrics"
                    ],
                    "id": "#main/collect_alignment_summary_metrics"
                },
                {
                    "run": "#collect_gc_bias_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/collect_gc_bias_metrics/cram"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/collect_gc_bias_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_gc_bias_metrics/reference"
                        }
                    ],
                    "out": [
                        "#main/collect_gc_bias_metrics/gc_bias_metrics",
                        "#main/collect_gc_bias_metrics/gc_bias_metrics_chart",
                        "#main/collect_gc_bias_metrics/gc_bias_metrics_summary"
                    ],
                    "id": "#main/collect_gc_bias_metrics"
                },
                {
                    "run": "#collect_insert_size_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/collect_insert_size_metrics/cram"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/collect_insert_size_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_insert_size_metrics/reference"
                        }
                    ],
                    "out": [
                        "#main/collect_insert_size_metrics/insert_size_metrics",
                        "#main/collect_insert_size_metrics/insert_size_histogram"
                    ],
                    "id": "#main/collect_insert_size_metrics"
                },
                {
                    "run": "#collect_wgs_metrics.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/collect_wgs_metrics/cram"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/collect_wgs_metrics/intervals"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_wgs_metrics/reference"
                        }
                    ],
                    "out": [
                        "#main/collect_wgs_metrics/wgs_metrics"
                    ],
                    "id": "#main/collect_wgs_metrics"
                },
                {
                    "run": "#workflow.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/cram_to_bam/cram"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/cram_to_bam/reference"
                        }
                    ],
                    "out": [
                        "#main/cram_to_bam/bam"
                    ],
                    "id": "#main/cram_to_bam"
                },
                {
                    "run": "#samtools_flagstat.cwl",
                    "in": [
                        {
                            "source": "#main/cram",
                            "id": "#main/samtools_flagstat/cram"
                        }
                    ],
                    "out": [
                        "#main/samtools_flagstat/flagstats"
                    ],
                    "id": "#main/samtools_flagstat"
                },
                {
                    "run": "#verify_bam_id.cwl",
                    "in": [
                        {
                            "source": "#main/cram_to_bam/bam",
                            "id": "#main/verify_bam_id/bam"
                        },
                        {
                            "source": "#main/omni_vcf",
                            "id": "#main/verify_bam_id/vcf"
                        }
                    ],
                    "out": [
                        "#main/verify_bam_id/verify_bam_id_metrics",
                        "#main/verify_bam_id/verify_bam_id_depth"
                    ],
                    "id": "#main/verify_bam_id"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
